(function(Drupal, drupalSettings) {
  'use strict';
  Drupal.behaviors.dripletLog = {
    attach: function(context, settings) {
      if (context !== document) {
        return;
      }

      // Get the log table and its body
      const table = document.getElementById('driplet-log-table');
      if (!table) return;

      // Get or create tbody
      let tbody = table.querySelector('tbody');
      if (!tbody) {
        tbody = document.createElement('tbody');
        table.appendChild(tbody);
      }

      // Get the WS endpoint and JWT endpoint
      const wsEndpoint = drupalSettings.driplet.ws_endpoint;
      const jwtEndpoint = window.location.origin + '/api/driplet/jwt';

      // Get the singleton instance (connection is handled automatically)
      const client = DripletClient.getInstance(wsEndpoint, jwtEndpoint);

      // Set up topics we want to subscribe to
      client.setTopics(['driplet-log']);

      // Set up message handler
      client.onMessage((rawMessage) => {
        console.log('Received message:', rawMessage);

        // Check if this message is for our topic
        if (rawMessage.topic !== 'driplet-log') return;

        // Get actual message body
        const message = rawMessage.message;

        // Remove "Waiting for logs..." if it exists
        const emptyRow = tbody.querySelector('tr.empty-text');
        if (emptyRow) {
          emptyRow.remove();
        }

        // Create new row
        const row = tbody.insertRow(0);
        row.className = `severity-${message.severity}`;

        // Severity
        const severityCell = row.insertCell();
        severityCell.textContent = message.severity != null ? Drupal.t(message.severity.toString()) : '-';

        // Type
        const typeCell = row.insertCell();
        typeCell.textContent = message.type || '-';

        // Date
        const dateCell = row.insertCell();
        const date = message.timestamp ? new Date(message.timestamp * 1000) : new Date();
        dateCell.textContent = date.toLocaleString();

        // Message
        const messageCell = row.insertCell();
        if (message.link) {
          const link = document.createElement('a');
          link.href = message.link;
          link.textContent = message.message || '';
          messageCell.appendChild(link);
        } else {
          messageCell.textContent = message.message || '';
        }

        // User
        const userCell = row.insertCell();
        userCell.textContent = message.uid != null ? message.uid : '-';

        // Limit to 50 rows
        if (tbody.rows.length > 50) {
          tbody.deleteRow(tbody.rows.length - 1);
        }
      });
    }
  };
})(Drupal, drupalSettings);
