(function(Drupal, drupalSettings) {
  'use strict';

  Drupal.behaviors.dripletNotify = {
    createNotification: function(message, wrapper) {
      // Create notification element
      const notification = document.createElement('div');
      notification.className = `driplet-notify ${message.notifyType || 'default'}`;
      // If it's a timed notification, add the timed class
      if (message.type === 'notify') {
        notification.classList.add('timed');
        // Remove notification after 12 seconds
        setTimeout(() => {
          notification.remove();
        }, 12000);
      }
      // Create content
      const content = document.createElement('div');
      content.className = 'driplet-notify-content';
      content.innerHTML = message.content;
      notification.appendChild(content);
      // Create close button
      const close = document.createElement('button');
      close.className = 'driplet-notify-close';
      close.innerHTML = '×';
      close.setAttribute('aria-label', 'Close notification');
      close.addEventListener('click', function() {
        notification.remove();
      });
      notification.appendChild(close);
      // Add to wrapper
      wrapper.appendChild(notification);
    },

    attach: function(context, settings) {
      if (context !== document) {
        return;
      }

      // Get the notification wrapper
      const wrapper = document.getElementById('driplet-notify-wrapper');
      if (!wrapper) return;

      // Get the WS endpoint and JWT endpoint
      const wsEndpoint = drupalSettings.driplet.ws_endpoint;
      const jwtEndpoint = window.location.origin + '/api/driplet/jwt';

      // Get the Driplet client instance (connection is handled automatically)
      const client = DripletClient.getInstance(wsEndpoint, jwtEndpoint);

      // Set driplet-notify topic
      client.setTopics(['driplet-notify']);

      // Set up message handler
      client.onMessage((rawMessage) => {
        console.log('Received a message from Driplet:', rawMessage);

        // Check if this message is for driplet-notify topic
        if (rawMessage.topic !== 'driplet-notify') return;

        // Get message body
        const message = rawMessage.message;

        // Handle both notify and notify-persist messages
        if (message.type !== 'notify' && message.type !== 'notify-persist') {
          return;
        }
        this.createNotification(message, wrapper);
      });
    }
  };
})(Drupal, drupalSettings);
