<?php

namespace Drupal\driplet\Service;

use Driplet\Client\DripletClient;
use Driplet\Exception\DripletException;
use Driplet\Message\MessageBuilder;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Service for sending messages to Driplet.
 */
class DripletService {

  /**
   * The Driplet client.
   *
   * @var \Driplet\Client\DripletClient
   */
  protected DripletClient $client;

  /**
   * Constructs a new DripletService.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory service.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $config = $config_factory->get('driplet.settings');

    $this->client = new DripletClient(
      $config->get('driplet_api_endpoint'),
      $config->get('driplet_api_secret')
    );
  }

  /**
   * Creates a new message builder instance.
   *
   * @return \Driplet\Message\MessageBuilder
   *   A new message builder instance.
   */
  public function createMessage(): MessageBuilder {
    return $this->client->createMessage();
  }

  /**
   * Send a message using the builder.
   *
   * @param \Driplet\Message\MessageBuilder $builder
   *   The message builder containing the message to send.
   *
   * @return bool
   *   TRUE if the message was sent successfully, FALSE otherwise.
   */
  public function sendMessage(MessageBuilder $builder): bool {
      try {
          return $this->client->sendMessage($builder);
      }
      catch (DripletException $e) {
          throw new \RuntimeException('Failed to send Driplet message: ' . $e->getMessage(), 0, $e);
      }
  }
}
